.. fwdpp documentation master file, created by
   sphinx-quickstart on Fri Nov  6 09:10:49 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to fwdpp's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   rst/introduction
   rst/distribution
   rst/building

.. toctree::
   :caption: Fundamental types

   rst/fundamentaltypes
   rst/mutations
   rst/haploidgenome
   rst/diploids
   rst/typedefs
   rst/rng

.. toctree::
   :caption: Mutation and recombination

   rst/geneticmaps

.. toctree::
   :caption: Technical documentation

   rst/changelog
   rst/develpersguide



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
